@@ -17,6 +17,14 @@
  * Boston, MA 02111-1307, USA.
  */
 
+/**
+ * SECTION: gtkplotcanvasplot
+ * @short_description: 
+ *
+ * FIXME:: need long description
+ */
+
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -65,36 +73,39 @@ static GtkPlotCanvasChildClass *parent_class = NULL;
 extern GtkPlotCanvasPos possible_selection	(GtkAllocation area, 
 						 gint x, gint y);
 
-GtkType
+GType
 gtk_plot_canvas_plot_get_type (void)
 {
-  static GtkType plot_canvas_plot_type = 0;
+  static GType plot_canvas_plot_type = 0;
 
   if (!plot_canvas_plot_type)
     {
-      GtkTypeInfo plot_canvas_plot_info =
-      {
-	"GtkPlotCanvasPlot",
-	sizeof (GtkPlotCanvasPlot),
-	sizeof (GtkPlotCanvasPlotClass),
-	(GtkClassInitFunc) gtk_plot_canvas_plot_class_init,
-	(GtkObjectInitFunc) gtk_plot_canvas_plot_init,
-	/* reserved 1*/ NULL,
-        /* reserved 2 */ NULL,
-        (GtkClassInitFunc) NULL,
-      };
-
-      plot_canvas_plot_type = gtk_type_unique (gtk_plot_canvas_child_get_type(), &plot_canvas_plot_info);
+      plot_canvas_plot_type = g_type_register_static_simple (
+		gtk_plot_canvas_child_get_type(),
+		"GtkPlotCanvasPlot",
+		sizeof (GtkPlotCanvasPlotClass),
+		(GClassInitFunc) gtk_plot_canvas_plot_class_init,
+		sizeof (GtkPlotCanvasPlot),
+		(GInstanceInitFunc) gtk_plot_canvas_plot_init,
+		0);
     }
   return plot_canvas_plot_type;
 }
 
+/**
+ * gtk_plot_canvas_plot_new:
+ * @plot: a #GtkPlot.
+ *
+ *
+ *
+ * Return value:
+ */
 GtkPlotCanvasChild*
 gtk_plot_canvas_plot_new (GtkPlot *plot)
 {
   GtkPlotCanvasPlot *child;
                                                                                 
-  child = gtk_type_new (gtk_plot_canvas_plot_get_type ());
+  child = g_object_new (gtk_plot_canvas_plot_get_type (), NULL);
   child->plot = plot;
                                  
   return GTK_PLOT_CANVAS_CHILD (child);
@@ -117,7 +128,7 @@ gtk_plot_canvas_plot_class_init (GtkPlotCanvasChildClass *klass)
 {
   GtkObjectClass *object_class = (GtkObjectClass *)klass;
 
-  parent_class = gtk_type_class (gtk_plot_canvas_child_get_type ());
+  parent_class = g_type_class_ref (gtk_plot_canvas_child_get_type ());
 
   klass->draw = gtk_plot_canvas_plot_draw; 
   klass->move = gtk_plot_canvas_plot_move; 
@@ -135,7 +146,7 @@ static void
 gtk_plot_canvas_plot_destroy(GtkObject *object)
 {
   GtkWidget *widget = GTK_WIDGET(GTK_PLOT_CANVAS_PLOT(object)->plot);
-  gtk_widget_unref(widget);
+  g_object_unref(widget);
   widget->parent = NULL;
 }
 
@@ -149,14 +160,16 @@ gtk_plot_canvas_plot_draw 		(GtkPlotCanvas *canvas,
   gint height = child->allocation.height;
   gdouble m = canvas->magnification;
   GtkPlotPC *pc;
+  GtkAllocation allocation;
 
   if(width == 0 && height == 0) return;
 
   gtk_plot_set_drawable(plot, canvas->pixmap);
-  GTK_WIDGET(plot)->allocation.x = 0;
-  GTK_WIDGET(plot)->allocation.y = 0;
-  GTK_WIDGET(plot)->allocation.width = canvas->pixmap_width;
-  GTK_WIDGET(plot)->allocation.height = canvas->pixmap_height;
+  allocation.x = 0;
+  allocation.y = 0;
+  allocation.width = canvas->pixmap_width;
+  allocation.height = canvas->pixmap_height;
+  gtk_widget_set_allocation(GTK_WIDGET(plot), &allocation);
   gtk_plot_set_magnification(plot, m);
   reset_plot_allocation(canvas, plot_child);
 
@@ -374,16 +387,18 @@ static void
 gtk_plot_canvas_plot_size_allocate	(GtkPlotCanvas *canvas,
 					 GtkPlotCanvasChild *child)
 {
+  GtkAllocation allocation;
   GtkPlot *plot = GTK_PLOT_CANVAS_PLOT(child)->plot;
   if(!plot) return;
 
   switch(GTK_PLOT_CANVAS_PLOT(child)->pos){
     case GTK_PLOT_CANVAS_PLOT_IN_PLOT:
     case GTK_PLOT_CANVAS_PLOT_OUT:
-      GTK_WIDGET(plot)->allocation.x = 0;
-      GTK_WIDGET(plot)->allocation.y = 0;
-      GTK_WIDGET(plot)->allocation.width = canvas->pixmap_width;
-      GTK_WIDGET(plot)->allocation.height = canvas->pixmap_height;
+      allocation.x = 0;
+      allocation.y = 0;
+      allocation.width = canvas->pixmap_width;
+      allocation.height = canvas->pixmap_height;
+      gtk_widget_set_allocation(GTK_WIDGET(plot), &allocation);
 
       if(!GTK_WIDGET(plot)->parent) 
         gtk_widget_set_parent(GTK_WIDGET(plot), GTK_WIDGET(canvas));
