@@ -17,6 +17,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
+/**
+ * SECTION: gtkplotflux
+ * @short_description: 
+ *
+ * FIXME:: Need long description.
+ */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -34,13 +41,13 @@ static void gtk_plot_flux_class_init 	(GtkPlotFluxClass *klass);
 static void gtk_plot_flux_init 		(GtkPlotFlux *data);
 static void gtk_plot_flux_destroy 	(GtkObject *data);
 static void gtk_plot_flux_get_property  (GObject      *object,
-                                         guint            prop_id,
-                                         GValue          *value,
-                                         GParamSpec      *pspec);
+                                         guint        prop_id,
+                                         GValue       *value,
+                                         GParamSpec   *pspec);
 static void gtk_plot_flux_set_property  (GObject      *object,
-                                         guint            prop_id,
-                                         const GValue          *value,
-                                         GParamSpec      *pspec);
+                                         guint        prop_id,
+                                         const GValue *value,
+                                         GParamSpec   *pspec);
 
 static void gtk_plot_flux_get_legend_size(GtkPlotData *data, 
 					 gint *width, gint *height);
@@ -79,26 +86,21 @@ enum {
 
 static GtkPlotDataClass *parent_class = NULL;
 
-GtkType
+GType
 gtk_plot_flux_get_type (void)
 {
-  static GtkType data_type = 0;
+  static GType data_type = 0;
 
   if (!data_type)
     {
-      GtkTypeInfo data_info =
-      {
-	"GtkPlotFlux",
-	sizeof (GtkPlotFlux),
-	sizeof (GtkPlotFluxClass),
-	(GtkClassInitFunc) gtk_plot_flux_class_init,
-	(GtkObjectInitFunc) gtk_plot_flux_init,
-	/* reserved 1*/ NULL,
-        /* reserved 2 */ NULL,
-        (GtkClassInitFunc) NULL,
-      };
-
-      data_type = gtk_type_unique (gtk_plot_data_get_type(), &data_info);
+      data_type = g_type_register_static_simple (
+		gtk_plot_data_get_type(),
+		"GtkPlotFlux",
+		sizeof (GtkPlotFluxClass),
+		(GClassInitFunc) gtk_plot_flux_class_init,
+		sizeof (GtkPlotFlux),
+		(GInstanceInitFunc) gtk_plot_flux_init,
+		0);
     }
   return data_type;
 }
@@ -111,7 +113,7 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
   GtkPlotDataClass *data_class;
   GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
-  parent_class = gtk_type_class (gtk_plot_data_get_type ());
+  parent_class = g_type_class_ref (gtk_plot_data_get_type ());
 
   object_class = (GtkObjectClass *) klass;
   widget_class = (GtkWidgetClass *) klass;
@@ -121,6 +123,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
   gobject_class->get_property = gtk_plot_flux_get_property;
   object_class->destroy = gtk_plot_flux_destroy;
 
+
+  /**
+   * GtkPlotFlux:centered:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_CENTERED,
   g_param_spec_boolean ("centered",
@@ -128,6 +136,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            FALSE,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:style:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_STYLE,
   g_param_spec_int ("style",
@@ -135,6 +149,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            0,G_MAXINT,0,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:width:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_WIDTH,
   g_param_spec_int ("width",
@@ -142,6 +162,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            0,G_MAXINT,0,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:length:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_LENGTH,
   g_param_spec_int ("length",
@@ -149,6 +175,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            0,G_MAXINT,0,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:scale_max:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_SCALE_MAX,
   g_param_spec_double ("scale_max",
@@ -156,6 +188,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            0,G_MAXDOUBLE,0,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:size_max:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_SIZE_MAX,
   g_param_spec_int ("size_max",
@@ -163,6 +201,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            0,G_MAXINT,0,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:show_scale:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_SHOW_SCALE,
   g_param_spec_boolean ("show_scale",
@@ -170,6 +214,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            FALSE,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:labels_precision:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_LABEL_PRECISION,
   g_param_spec_int ("labels_precision",
@@ -177,6 +227,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            0,G_MAXINT,0,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:labels_style:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_LABEL_STYLE,
   g_param_spec_int ("labels_style",
@@ -184,6 +240,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            0,G_MAXINT,0,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:labels_prefix:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_LABEL_PREFIX,
   g_param_spec_string ("labels_prefix",
@@ -191,6 +253,12 @@ gtk_plot_flux_class_init (GtkPlotFluxClass *klass)
                            P_(""),
                            NULL,
                            G_PARAM_READABLE|G_PARAM_WRITABLE));
+
+  /**
+   * GtkPlotFlux:labels_suffix:
+   *
+   *
+   **/
   g_object_class_install_property (gobject_class,
                            ARG_LABEL_SUFFIX,
   g_param_spec_string ("labels_suffix",
@@ -368,7 +436,7 @@ gtk_plot_flux_new ()
 {
   GtkWidget *widget;
 
-  widget = gtk_type_new (gtk_plot_flux_get_type ());
+  widget = gtk_widget_new (gtk_plot_flux_get_type (), NULL);
 
   return (widget);
 }
@@ -398,21 +466,23 @@ gtk_plot_flux_draw_symbol(GtkPlotData *dataset,
   gdouble m;
   gdouble x1 = 0.0, y1 = 0.0, x2 = 0.0, y2=0.0;
   gdouble factor, size, xm;
+  GtkAllocation allocation;
 
   g_return_if_fail(GTK_IS_PLOT_FLUX(dataset));
 
   flux = GTK_PLOT_FLUX(dataset);
 
   g_return_if_fail(dataset->plot != NULL);
-  g_return_if_fail(GTK_WIDGET_VISIBLE(dataset->plot));
+  g_return_if_fail(gtk_widget_get_visible(GTK_WIDGET(dataset->plot)));
 
   plot = dataset->plot;
 
   m = plot->magnification;
-  area.x = GTK_WIDGET(plot)->allocation.x;
-  area.y = GTK_WIDGET(plot)->allocation.y;
-  area.width = GTK_WIDGET(plot)->allocation.width;
-  area.height = GTK_WIDGET(plot)->allocation.height;
+  gtk_widget_get_allocation( GTK_WIDGET(plot), &allocation);
+  area.x = allocation.x;
+  area.y = allocation.y;
+  area.width = allocation.width;
+  area.height = allocation.height;
 
   clip_area.x = area.x + roundint(plot->x * area.width);
   clip_area.y = area.y + roundint(plot->y * area.height);
@@ -492,11 +562,11 @@ gtk_plot_flux_get_legend_size(GtkPlotData *data, gint *width, gint *height)
     gtk_plot_axis_parse_label(data->gradient, flux->scale_max, flux->labels_precision, flux->labels_style, text);
     if(flux->labels_prefix){
       g_snprintf(aux_text, 100, "%s%s", flux->labels_prefix, text);
-      strcpy(text, aux_text);
+      g_snprintf(text, 100, "%s", aux_text);
     }
     if(flux->labels_suffix) {
       g_snprintf(aux_text, 100, "%s%s", text, flux->labels_suffix);
-      strcpy(text, aux_text);
+      g_snprintf(text, 100, "%s", aux_text);
     }
 
     g_snprintf(new_label, 100, "%s", text);
@@ -524,19 +594,21 @@ gtk_plot_flux_draw_legend(GtkPlotData *data, gint x, gint y)
   gdouble m;
   gint line_width;
   gboolean centered;
+  GtkAllocation allocation;
 
   flux = GTK_PLOT_FLUX(data);
   centered = flux->centered;
 
   g_return_if_fail(data->plot != NULL);
   g_return_if_fail(GTK_IS_PLOT(data->plot));
-  g_return_if_fail(GTK_WIDGET_VISIBLE(data->plot));
+  g_return_if_fail(gtk_widget_get_visible(GTK_WIDGET(data->plot)));
 
   plot = data->plot;
-  area.x = GTK_WIDGET(plot)->allocation.x;
-  area.y = GTK_WIDGET(plot)->allocation.y;
-  area.width = GTK_WIDGET(plot)->allocation.width;
-  area.height = GTK_WIDGET(plot)->allocation.height;
+  gtk_widget_get_allocation( GTK_WIDGET(plot), &allocation);
+  area.x = allocation.x;
+  area.y = allocation.y;
+  area.width = allocation.width;
+  area.height = allocation.height;
 
   m = plot->magnification;
   legend = plot->legends_attr;
@@ -575,12 +647,12 @@ gtk_plot_flux_draw_legend(GtkPlotData *data, gint x, gint y)
     if(flux->labels_prefix){
       gchar aux_text[100];
       g_snprintf(aux_text, 100, "%s%s", flux->labels_prefix, text_max);
-      strcpy(text_max, aux_text);
+      g_snprintf(text_max, 100, "%s", aux_text);
     }
     if(flux->labels_suffix){
       gchar aux_text[100];
       g_snprintf(aux_text, 100, "%s%s", text_max, flux->labels_suffix);
-      strcpy(text_max, aux_text);
+      g_snprintf(text_max, 100, "%s", aux_text);
     }
     g_snprintf(new_label, 100, "%s", text_max);
 
@@ -674,6 +746,15 @@ gtk_plot_flux_draw_arrow(GtkPlotFlux *flux, gdouble x1, gdouble y1, gdouble x2,
   }
 }
 
+/**
+ * gtk_plot_flux_set_arrow:
+ * @flux:
+ * @arrow_length:
+ * @arrow_width:
+ * @arrow_style:
+ *
+ *
+ */
 void
 gtk_plot_flux_set_arrow (GtkPlotFlux *flux, 
                          gint arrow_length, 
@@ -685,6 +766,15 @@ gtk_plot_flux_set_arrow (GtkPlotFlux *flux,
   flux->arrow_style = arrow_style;
 }
 
+/**
+ * gtk_plot_flux_get_arrow:
+ * @flux:
+ * @arrow_length:
+ * @arrow_width:
+ * @arrow_style:
+ *
+ *
+ */
 void
 gtk_plot_flux_get_arrow (GtkPlotFlux *flux, 
                          gint *arrow_length, 
@@ -696,48 +786,105 @@ gtk_plot_flux_get_arrow (GtkPlotFlux *flux,
   *arrow_style = flux->arrow_style;
 }
 
+/**
+ * gtk_plot_flux_center:
+ * @flux:
+ * @center:
+ *
+ *
+ */
 void
 gtk_plot_flux_center (GtkPlotFlux *flux, gboolean center)
 {
   flux->centered = center;
 } 
 
+/**
+ * gtk_plot_flux_is_centered:
+ * @flux:
+ *
+ *
+ *
+ * Return value:
+ */
 gboolean
 gtk_plot_flux_is_centered (GtkPlotFlux *flux)
 {
   return(flux->centered);
 } 
 
+/**
+ * gtk_plot_flux_show_scale:
+ * @flux:
+ * @show:
+ *
+ *
+ */
 void            
 gtk_plot_flux_show_scale        (GtkPlotFlux *flux, gboolean show)
 {
   flux->show_scale = show;
 }
 
+/**
+ * gtk_plot_flux_set_scale_max:
+ * @flux:
+ * @scale_max:
+ *
+ *
+ */
 void            
 gtk_plot_flux_set_scale_max     (GtkPlotFlux *flux, gdouble scale_max)
 {
   flux->scale_max = fabs(scale_max);
 }
 
+/**
+ * gtk_plot_flux_set_size_max:
+ * @flux:
+ * @size_max:
+ *
+ *
+ */
 void            
 gtk_plot_flux_set_size_max      (GtkPlotFlux *flux, guint size_max)
 {
   flux->size_max = size_max;
 }
 
+/**
+ * gtk_plot_flux_set_labels_precision:
+ * @flux:
+ * @precision:
+ *
+ *
+ */
 void
 gtk_plot_flux_set_labels_precision (GtkPlotFlux *flux, gint precision)
 {
   flux->labels_precision = precision;
 }
 
+/**
+ * gtk_plot_flux_set_labels_style:
+ * @flux:
+ * @style:
+ *
+ *
+ */
 void
 gtk_plot_flux_set_labels_style (GtkPlotFlux *flux, GtkPlotLabelStyle style)
 {
   flux->labels_style = style;
 }
 
+/**
+ * gtk_plot_flux_set_labels_prefix:
+ * @flux:
+ * @prefix:
+ *
+ *
+ */
 void
 gtk_plot_flux_set_labels_prefix (GtkPlotFlux *flux, const gchar *prefix)
 {
@@ -747,6 +894,13 @@ gtk_plot_flux_set_labels_prefix (GtkPlotFlux *flux, const gchar *prefix)
     flux->labels_prefix = g_strdup(prefix);
 }
 
+/**
+ * gtk_plot_flux_set_labels_suffix:
+ * @flux:
+ * @suffix:
+ *
+ *
+ */
 void
 gtk_plot_flux_set_labels_suffix (GtkPlotFlux *flux, const gchar *suffix)
 {
